package Riap;

our $DATE = '2014-10-23'; # DATE
our $VERSION = '1.2.0'; # VERSION

1;
# ABSTRACT: Rinci access protocol

__END__

=pod

=encoding UTF-8

=head1 NAME

Riap - Rinci access protocol

=head1 VERSION

This document describes version 1.2.0 of Riap (from Perl distribution Riap), released on 2014-10-23.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Riap>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Riap>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Riap>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
